Learn R Programming

SDLfilter (version 1.2.1)

tidalplane: Tidal plane table for Sandy Strait, Australia

Description

A semidiurnal tidal plane table containing the height of the mean tidal planes and the average tide time differences at different places within Sandy Strait.

Usage

tidalplane

Arguments

Format

A data frame with 2 rows and 6 variables:

secondary.port

identifier for a station at which tide is only predicted using tidal records observed at the related standard port

standard.port

identifier for a tidal observation station

lat

latitude in decimal degrees

lon

longitude in decimal degrees

datumDiff

baseline difference in meters between bathymetry and tidal observations/predictions if each data uses different datum (e.g. LAT and MSL)

timeDiff

time difference between standard port and its associated secondary port