Learn R Programming

SDLfilter (version 1.2.1)

turtle: Green turtle tracking data

Description

A dataset containing Fastloc GPS locations of a green turtle tracked in Sandy Strait, Australia.

Usage

turtle

Arguments

Format

A data frame with 429 rows and 5 variables:

id

identifier for each animal

DateTime

date & time in class POSIXct

lat

latitude in decimal degrees

lon

longitude in decimal degrees

qi

numerical quality index associated with each fix where the greater number represents better quality (e.g. number of GPS satellites used for estimation)