A semidiurnal tidal plane table containing the height of the mean tidal planes and the average tide time differences at different places within Sandy Strait.
tidalplaneA data frame with 2 rows and 6 variables:
identifier for a station at which tide is only predicted using tidal records observed at the related standard port
identifier for a tidal observation station
latitude in decimal degrees
longitude in decimal degrees
baseline difference in meters between bathymetry and tidal observations/predictions if each data uses different datum (e.g. LAT and MSL)
time difference between standard port and its associated secondary port