A dataset containing Fastloc GPS locations of a green turtle tracked in Sandy Strait, Australia.
turtleA data frame with 429 rows and 5 variables:
identifier for each animal
date & time in class POSIXct
latitude in decimal degrees
longitude in decimal degrees
numerical quality index associated with each fix where the greater number represents better quality (e.g. number of GPS satellites used for estimation)