A dataset containing Fastloc GPS locations of a green turtle tracked in Moreton Bay, Australia.
turtle2A data frame with 276 rows and 5 variables:
identifier for each animal
date & time in class POSIXct
latitude in decimal degrees
longitude in decimal degrees
numerical quality index associated with each fix where the greater number represents better quality (e.g. number of GPS satellites used for estimation)